.data
.p2align 5
mask_0_1:
.byte 0
.byte 255
.byte 5
.byte 3
.byte 10
.byte 8
.byte 15
.byte 7
.byte 14
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 11
.byte 255
.byte 10
.byte 255

mask_1_1:
.word 0x1
.word 0x2
.word 0x4
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8
.word 0x10
.word 0x0

mask_2_1:
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2

mask_3_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_4_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255

mask_5_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0

mask_6_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_7_1:
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 1
.byte 14
.byte 6
.byte 13
.byte 255
.byte 255
.byte 1
.byte 255
.byte 0
.byte 7
.byte 5
.byte 12
.byte 10
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_8_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x0
.word 0x8000
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_9_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0

mask_10_1:
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_11_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_12_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_13_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_14_1:
.byte 11
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 1
.byte 255
.byte 255
.byte 3
.byte 255
.byte 2
.byte 9
.byte 7
.byte 14
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_15_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x80
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_16_1:
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0

mask_17_1:
.word 0x0
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_18_1:
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_19_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_20_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_21_1:
.byte 255
.byte 2
.byte 0
.byte 7
.byte 5
.byte 12
.byte 10
.byte 255
.byte 9
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 6
.byte 13
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255

mask_22_1:
.word 0x100
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8

mask_23_1:
.word 0x0
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_24_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_25_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_26_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_27_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_28_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 0
.byte 7
.byte 5
.byte 12
.byte 10
.byte 255
.byte 9
.byte 255
.byte 14
.byte 255
.byte 3
.byte 10
.byte 8
.byte 15
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 1
.byte 8

mask_29_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800

mask_30_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80

mask_31_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_32_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_33_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_34_1:
.byte 255
.byte 13
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 2
.byte 9
.byte 7
.byte 14
.byte 12
.byte 255
.byte 255
.byte 255

mask_35_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x200
.word 0x0
.word 0x0

mask_36_1:
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x0

mask_37_1:
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_38_1:
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_39_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_40_1:
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_41_1:
.byte 255
.byte 9
.byte 1
.byte 14
.byte 255
.byte 13
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 255

mask_42_1:
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0

mask_43_1:
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x0

mask_44_1:
.word 0x0
.word 0x80
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_45_1:
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_46_1:
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_47_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_48_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 2
.byte 9
.byte 7
.byte 14
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 11
.byte 3
.byte 10
.byte 8
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255

mask_49_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0

mask_50_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_51_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_52_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_53_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_54_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_55_1:
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 2
.byte 9
.byte 7
.byte 14
.byte 12
.byte 3
.byte 255
.byte 8
.byte 0
.byte 13
.byte 5
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_56_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x2
.word 0x4
.word 0x8
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_57_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_58_1:
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_59_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_60_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_61_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_62_1:
.byte 6
.byte 255
.byte 11
.byte 3
.byte 10
.byte 255
.byte 15
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 4
.byte 11
.byte 9

mask_63_1:
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1

mask_64_1:
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000

mask_65_1:
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_66_1:
.byte 0
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_67_1:
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_68_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_69_1:
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 11
.byte 3
.byte 10
.byte 255
.byte 15
.byte 255
.byte 14
.byte 255
.byte 255
.byte 0
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 6
.byte 13

mask_70_1:
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x100

mask_71_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10

mask_72_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_73_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255

mask_74_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0

mask_75_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_76_1:
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 6
.byte 4
.byte 11
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 13
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_77_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0

mask_78_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0

mask_79_1:
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_80_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_81_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0

mask_82_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_83_1:
.byte 7
.byte 14
.byte 6
.byte 13
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 0
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255

mask_84_1:
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x0
.word 0x400
.word 0x800
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0

mask_85_1:
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0

mask_86_1:
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_87_1:
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_88_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0

mask_89_1:
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_90_1:
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 0
.byte 13
.byte 5
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255

mask_91_1:
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40

mask_92_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_93_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_94_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_95_1:
.word 0x0
.word 0x0
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_96_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_97_1:
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 13
.byte 5
.byte 12
.byte 255
.byte 11
.byte 8
.byte 6
.byte 13
.byte 11
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4

mask_98_1:
.word 0x0
.word 0x8
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000

mask_99_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_100_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_101_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_102_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_103_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_104_1:
.byte 11
.byte 9
.byte 255
.byte 8
.byte 15
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255
.byte 14

mask_105_1:
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x2000
.word 0x0

mask_106_1:
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400

mask_107_1:
.word 0x0
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_108_1:
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 255

mask_109_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x0

mask_110_1:
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_111_1:
.byte 5
.byte 12
.byte 10
.byte 255
.byte 9
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 1
.byte 8
.byte 255
.byte 13
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255

mask_112_1:
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x1000
.word 0x0
.word 0x0
.word 0x0

mask_113_1:
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x200
.word 0x0
.word 0x0

mask_114_1:
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_115_1:
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_116_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0

mask_117_1:
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_118_1:
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 11
.byte 3
.byte 10
.byte 8
.byte 15
.byte 255
.byte 14
.byte 255
.byte 255
.byte 2
.byte 9
.byte 7
.byte 14
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255

mask_119_1:
.word 0x0
.word 0x800
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20

mask_120_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_121_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_122_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_123_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_124_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_125_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 11
.byte 3
.byte 10
.byte 8
.byte 15
.byte 255
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2

mask_126_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000

mask_127_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_128_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_129_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_130_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_131_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_132_1:
.byte 9
.byte 7
.byte 14
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 1
.byte 8
.byte 255
.byte 13
.byte 255
.byte 12

mask_133_1:
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x1000
.word 0x0

mask_134_1:
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x200

mask_135_1:
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_136_1:
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255

mask_137_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0

mask_138_1:
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_139_1:
.byte 255
.byte 255
.byte 4
.byte 2
.byte 9
.byte 7
.byte 14
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 3
.byte 10
.byte 255
.byte 15
.byte 255

mask_140_1:
.word 0x0
.word 0x1
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x4
.word 0x8
.word 0x10

mask_141_1:
.word 0x0
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0

mask_142_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_143_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255

mask_144_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1

mask_145_1:
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_146_1:
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 0
.byte 13
.byte 5
.byte 12
.byte 10
.byte 255
.byte 0
.byte 0
.byte 5
.byte 255
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_147_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x20
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_148_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0

mask_149_1:
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_150_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_151_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_152_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_153_1:
.byte 10
.byte 255
.byte 15
.byte 255
.byte 14
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 0
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 6
.byte 13
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_154_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x0
.word 0x40
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_155_1:
.word 0x8
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0

mask_156_1:
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_157_1:
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_158_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_159_1:
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_160_1:
.byte 0
.byte 255
.byte 255
.byte 6
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 5
.byte 12
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 3

mask_161_1:
.word 0x80
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4

mask_162_1:
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000

mask_163_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_164_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_165_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_166_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_167_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 0
.byte 255
.byte 6
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 13
.byte 255
.byte 2
.byte 15
.byte 7
.byte 14
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 0
.byte 7

mask_168_1:
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x400

mask_169_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40

mask_170_1:
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_171_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_172_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_173_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_174_1:
.byte 5
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 6
.byte 13
.byte 11
.byte 255
.byte 255
.byte 255

mask_175_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x100
.word 0x0
.word 0x0

mask_176_1:
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0

mask_177_1:
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_178_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_179_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0

mask_180_1:
.byte 255
.byte 8
.byte 0
.byte 13
.byte 5
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 8
.byte 15
.byte 13
.byte 255
.byte 255

mask_181_1:
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0

mask_182_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x0

mask_183_1:
.word 0x0
.word 0x40
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_184_1:
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_185_1:
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0

mask_186_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 1
.byte 8
.byte 6
.byte 13
.byte 11
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255
.byte 5
.byte 255
.byte 10
.byte 2
.byte 15
.byte 7
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_187_1:
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_188_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_189_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_190_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_191_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_192_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_193_1:
.byte 15
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 1
.byte 8
.byte 6
.byte 13
.byte 11
.byte 2
.byte 0
.byte 7
.byte 255
.byte 12
.byte 4
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_194_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x1
.word 0x2
.word 0x4
.word 0x8
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_195_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_196_1:
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_197_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_198_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_199_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_200_1:
.byte 5
.byte 255
.byte 10
.byte 2
.byte 15
.byte 7
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 8

mask_201_1:
.word 0x10
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0

mask_202_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x1000

mask_203_1:
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_204_1:
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255

mask_205_1:
.word 0x0
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0

mask_206_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 10
.byte 2
.byte 15
.byte 7
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 13
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 11
.byte 255

mask_207_1:
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x80

mask_208_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_209_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_210_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255

mask_211_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8

mask_212_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_213_1:
.byte 10
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 3
.byte 10
.byte 8
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 0
.byte 7
.byte 255
.byte 12
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_214_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x4
.word 0x8
.word 0x10
.word 0x0
.word 0x0
.word 0x0

mask_215_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0

mask_216_1:
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_217_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_218_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0

mask_219_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_220_1:
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 4
.byte 11
.byte 9
.byte 0
.byte 255
.byte 5
.byte 3
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_221_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_222_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_223_1:
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_224_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_225_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_226_1:
.byte 3
.byte 255
.byte 2
.byte 0
.byte 7
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 12

mask_227_1:
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x4000
.word 0x8000

mask_228_1:
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_229_1:
.word 0x0
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_230_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6

mask_231_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800

mask_232_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_233_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 0
.byte 13
.byte 5
.byte 12
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 3
.byte 255

mask_234_1:
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0

mask_235_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4

mask_236_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_237_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_238_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_239_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 3
.byte 10
.byte 255
.byte 15
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255

mask_240_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x4
.word 0x8
.word 0x10
.word 0x0
.word 0x0

mask_241_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x2
.word 0x0

mask_242_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_243_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0

mask_244_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_245_1:
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 0
.byte 7
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_246_1:
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x200
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_247_1:
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x0
.word 0x0
.word 0x0

mask_248_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_249_1:
.byte 255
.byte 255
.byte 3
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_250_1:
.word 0x0
.word 0x4
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_251_1:
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 5
.byte 255
.byte 4
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 6
.byte 13
.byte 11
.byte 255
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_252_1:
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_253_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_254_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_255_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_256_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_257_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_258_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 10
.byte 2
.byte 15
.byte 7
.byte 14
.byte 255
.byte 3
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1

mask_259_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000

mask_260_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_261_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x0
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_262_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_263_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_264_1:
.byte 255
.byte 6
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 0
.byte 7
.byte 5
.byte 12
.byte 255
.byte 11

mask_265_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x400
.word 0x800
.word 0x0

mask_266_1:
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x100

mask_267_1:
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_268_1:
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_269_1:
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_270_1:
.byte 255
.byte 2
.byte 255
.byte 1
.byte 8
.byte 6
.byte 13
.byte 11
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255

mask_271_1:
.word 0x8000
.word 0x0
.word 0x1
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0

mask_272_1:
.word 0x0
.word 0x1000
.word 0x2000
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0

mask_273_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_274_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_275_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_276_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 0
.byte 7
.byte 255
.byte 6
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 9
.byte 255
.byte 8
.byte 15
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_277_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0

mask_278_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0

mask_279_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_280_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_281_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_282_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_283_1:
.byte 15
.byte 7
.byte 14
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 0
.byte 7
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_284_1:
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x8
.word 0x0
.word 0x20
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_285_1:
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_286_1:
.word 0x8000
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_287_1:
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_288_1:
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_289_1:
.byte 255
.byte 255
.byte 4
.byte 255
.byte 3
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 4
.byte 11
.byte 9
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 2

mask_290_1:
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2

mask_291_1:
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000

mask_292_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_293_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_294_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_295_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 3
.byte 10
.byte 8
.byte 15
.byte 13
.byte 255
.byte 12
.byte 255
.byte 1
.byte 8
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6

mask_296_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x200

mask_297_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x40
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_298_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_299_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_300_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_301_1:
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 11
.byte 255
.byte 10
.byte 255
.byte 15
.byte 255

mask_302_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x40
.word 0x80
.word 0x0
.word 0x0

mask_303_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20

mask_304_1:
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_305_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_306_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0

mask_307_1:
.byte 255
.byte 7
.byte 255
.byte 12
.byte 4
.byte 11
.byte 9
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 2
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255

mask_308_1:
.word 0x1000
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_309_1:
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x0
.word 0x0

mask_310_1:
.word 0x0
.word 0x0
.word 0x40
.word 0x80
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_311_1:
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_312_1:
.word 0x100
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_313_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 6
.byte 255
.byte 5
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 2
.byte 9
.byte 1
.byte 14
.byte 6
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_314_1:
.word 0x0
.word 0x0
.word 0x4000
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x800
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_315_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_316_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_317_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_318_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

.text
.global PQCLEAN_NTRUHRSS701_AVX2_square_168_701
.global _PQCLEAN_NTRUHRSS701_AVX2_square_168_701
PQCLEAN_NTRUHRSS701_AVX2_square_168_701:
_PQCLEAN_NTRUHRSS701_AVX2_square_168_701:
vmovdqa 0(%rsi), %ymm0
vpshufb mask_0_1(%rip), %ymm0, %ymm5
vpand mask_1_1(%rip), %ymm5, %ymm1
vpand mask_2_1(%rip), %ymm5, %ymm2
vpand mask_3_1(%rip), %ymm5, %ymm3
vpshufb mask_4_1(%rip), %ymm0, %ymm5
vpand mask_5_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_6_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm8
vpshufb mask_7_1(%rip), %ymm8, %ymm5
vpand mask_8_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_9_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_10_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_11_1(%rip), %ymm8, %ymm5
vpand mask_12_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_13_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm0, %ymm5
vpsllq $1, %ymm0, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_14_1(%rip), %ymm6, %ymm5
vpand mask_15_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_16_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_17_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_18_1(%rip), %ymm6, %ymm5
vpand mask_19_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_20_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_21_1(%rip), %ymm8, %ymm5
vpand mask_22_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_23_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_24_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_25_1(%rip), %ymm8, %ymm5
vpand mask_26_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_27_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm6, %ymm5
vpsllq $1, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_28_1(%rip), %ymm7, %ymm5
vpand mask_29_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_30_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_31_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_32_1(%rip), %ymm7, %ymm5
vpand mask_33_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_34_1(%rip), %ymm8, %ymm5
vpand mask_35_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_36_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_37_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_38_1(%rip), %ymm8, %ymm5
vpand mask_39_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_40_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm7, %ymm6
vpshufb mask_41_1(%rip), %ymm6, %ymm5
vpand mask_42_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_43_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_44_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_45_1(%rip), %ymm6, %ymm5
vpand mask_46_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_47_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_48_1(%rip), %ymm8, %ymm5
vpand mask_49_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_50_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_51_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_52_1(%rip), %ymm8, %ymm5
vpand mask_53_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_54_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $62, %ymm7, %ymm5
vpsllq $2, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_55_1(%rip), %ymm6, %ymm5
vpand mask_56_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_57_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_58_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_59_1(%rip), %ymm6, %ymm5
vpand mask_60_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_61_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_62_1(%rip), %ymm8, %ymm5
vpand mask_63_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_64_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_65_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_66_1(%rip), %ymm8, %ymm5
vpand mask_67_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_68_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm6, %ymm7
vpshufb mask_69_1(%rip), %ymm7, %ymm5
vpand mask_70_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_71_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_72_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_73_1(%rip), %ymm7, %ymm5
vpand mask_74_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_75_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_76_1(%rip), %ymm8, %ymm5
vpand mask_77_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_78_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_79_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_80_1(%rip), %ymm8, %ymm5
vpand mask_81_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_82_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $62, %ymm6, %ymm5
vpsllq $2, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_83_1(%rip), %ymm7, %ymm5
vpand mask_84_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_85_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_86_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_87_1(%rip), %ymm7, %ymm5
vpand mask_88_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_89_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_90_1(%rip), %ymm8, %ymm5
vpand mask_91_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_92_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_93_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_94_1(%rip), %ymm8, %ymm5
vpand mask_95_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_96_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm5
vpsllq $1, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_97_1(%rip), %ymm6, %ymm5
vpand mask_98_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_99_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_100_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_101_1(%rip), %ymm6, %ymm5
vpand mask_102_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_103_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_104_1(%rip), %ymm8, %ymm5
vpand mask_105_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_106_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_107_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_108_1(%rip), %ymm8, %ymm5
vpand mask_109_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_110_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vmovdqa 32(%rsi), %ymm0
vpshufb mask_111_1(%rip), %ymm0, %ymm5
vpand mask_112_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_113_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_114_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_115_1(%rip), %ymm0, %ymm5
vpand mask_116_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_117_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm8
vpshufb mask_118_1(%rip), %ymm8, %ymm5
vpand mask_119_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_120_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_121_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_122_1(%rip), %ymm8, %ymm5
vpand mask_123_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_124_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm0, %ymm6
vpshufb mask_125_1(%rip), %ymm6, %ymm5
vpand mask_126_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_127_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_128_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_129_1(%rip), %ymm6, %ymm5
vpand mask_130_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_131_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_132_1(%rip), %ymm8, %ymm5
vpand mask_133_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_134_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_135_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_136_1(%rip), %ymm8, %ymm5
vpand mask_137_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_138_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $62, %ymm0, %ymm5
vpsllq $2, %ymm0, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_139_1(%rip), %ymm6, %ymm5
vpand mask_140_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_141_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_142_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_143_1(%rip), %ymm6, %ymm5
vpand mask_144_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_145_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_146_1(%rip), %ymm8, %ymm5
vpand mask_147_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_148_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_149_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_150_1(%rip), %ymm8, %ymm5
vpand mask_151_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_152_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm6, %ymm5
vpsllq $1, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_153_1(%rip), %ymm7, %ymm5
vpand mask_154_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_155_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_156_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_157_1(%rip), %ymm7, %ymm5
vpand mask_158_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_159_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_160_1(%rip), %ymm8, %ymm5
vpand mask_161_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_162_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_163_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_164_1(%rip), %ymm8, %ymm5
vpand mask_165_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_166_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm7, %ymm6
vpshufb mask_167_1(%rip), %ymm6, %ymm5
vpand mask_168_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_169_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_170_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_171_1(%rip), %ymm6, %ymm5
vpand mask_172_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_173_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_174_1(%rip), %ymm8, %ymm5
vpand mask_175_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_176_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_177_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_178_1(%rip), %ymm8, %ymm5
vpand mask_179_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpsrlq $62, %ymm7, %ymm5
vpsllq $2, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_180_1(%rip), %ymm6, %ymm5
vpand mask_181_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_182_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_183_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_184_1(%rip), %ymm6, %ymm5
vpand mask_185_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm8
vpshufb mask_186_1(%rip), %ymm8, %ymm5
vpand mask_187_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_188_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_189_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_190_1(%rip), %ymm8, %ymm5
vpand mask_191_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_192_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm6, %ymm5
vpsllq $1, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_193_1(%rip), %ymm7, %ymm5
vpand mask_194_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_195_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_196_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_197_1(%rip), %ymm7, %ymm5
vpand mask_198_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_199_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_200_1(%rip), %ymm8, %ymm5
vpand mask_201_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_202_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_203_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_204_1(%rip), %ymm8, %ymm5
vpand mask_205_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpsllq $1, %ymm7, %ymm6
vpshufb mask_206_1(%rip), %ymm6, %ymm5
vpand mask_207_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_208_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_209_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_210_1(%rip), %ymm6, %ymm5
vpand mask_211_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_212_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_213_1(%rip), %ymm8, %ymm5
vpand mask_214_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_215_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_216_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_217_1(%rip), %ymm8, %ymm5
vpand mask_218_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_219_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vmovdqa 64(%rsi), %ymm0
vpshufb mask_220_1(%rip), %ymm0, %ymm5
vpand mask_221_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_222_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_223_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_224_1(%rip), %ymm0, %ymm5
vpand mask_225_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm8
vpshufb mask_226_1(%rip), %ymm8, %ymm5
vpand mask_227_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_228_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_229_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_230_1(%rip), %ymm8, %ymm5
vpand mask_231_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_232_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm0, %ymm5
vpsllq $1, %ymm0, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_233_1(%rip), %ymm6, %ymm5
vpand mask_234_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_235_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_236_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_237_1(%rip), %ymm6, %ymm5
vpand mask_238_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm8
vpshufb mask_239_1(%rip), %ymm8, %ymm5
vpand mask_240_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_241_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpshufb mask_242_1(%rip), %ymm8, %ymm5
vpand mask_243_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_244_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm6, %ymm7
vpshufb mask_245_1(%rip), %ymm7, %ymm5
vpand mask_246_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_247_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_248_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_249_1(%rip), %ymm7, %ymm5
vpand mask_250_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_251_1(%rip), %ymm8, %ymm5
vpand mask_252_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_253_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_254_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_255_1(%rip), %ymm8, %ymm5
vpand mask_256_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_257_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $62, %ymm6, %ymm5
vpsllq $2, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_258_1(%rip), %ymm7, %ymm5
vpand mask_259_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_260_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_261_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_262_1(%rip), %ymm7, %ymm5
vpand mask_263_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpermq $78, %ymm7, %ymm8
vpshufb mask_264_1(%rip), %ymm8, %ymm5
vpand mask_265_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_266_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_267_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_268_1(%rip), %ymm8, %ymm5
vpand mask_269_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm5
vpsllq $1, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_270_1(%rip), %ymm6, %ymm5
vpand mask_271_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_272_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_273_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_274_1(%rip), %ymm6, %ymm5
vpand mask_275_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_276_1(%rip), %ymm8, %ymm5
vpand mask_277_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_278_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_279_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_280_1(%rip), %ymm8, %ymm5
vpand mask_281_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_282_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm6, %ymm7
vpshufb mask_283_1(%rip), %ymm7, %ymm5
vpand mask_284_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_285_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_286_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_287_1(%rip), %ymm7, %ymm5
vpand mask_288_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpermq $78, %ymm7, %ymm8
vpshufb mask_289_1(%rip), %ymm8, %ymm5
vpand mask_290_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_291_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_292_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_293_1(%rip), %ymm8, %ymm5
vpand mask_294_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpsrlq $62, %ymm6, %ymm5
vpsllq $2, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_295_1(%rip), %ymm7, %ymm5
vpand mask_296_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_297_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_298_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_299_1(%rip), %ymm7, %ymm5
vpand mask_300_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_301_1(%rip), %ymm8, %ymm5
vpand mask_302_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_303_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_304_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_305_1(%rip), %ymm8, %ymm5
vpand mask_306_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpsrlq $63, %ymm7, %ymm5
vpsllq $1, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_307_1(%rip), %ymm6, %ymm5
vpand mask_308_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_309_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_310_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_311_1(%rip), %ymm6, %ymm5
vpand mask_312_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm8
vpshufb mask_313_1(%rip), %ymm8, %ymm5
vpand mask_314_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_315_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_316_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpshufb mask_317_1(%rip), %ymm8, %ymm5
vpand mask_318_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vmovdqa %ymm1, 0(%rdi)
vmovdqa %ymm2, 32(%rdi)
vmovdqa %ymm3, 64(%rdi)
ret
